#
# spec file for package liblnk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	liblnk1
Name:           liblnk
Version:        20240423
Release:        1.5
Summary:        Library and tools to access the Windows Shortcut File (LNK) format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File Utilities
URL:            https://github.com/libyal/liblnk
Source:         https://github.com/libyal/liblnk/releases/download/%version/%name-alpha-%version.tar.gz
Source2:        https://github.com/libyal/liblnk/releases/download/%version/%name-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source8:        Windows_Shortcut_File_LNK_format.pdf
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfole) >= 20240416
BuildRequires:  pkgconfig(libfwps) >= 20240417
BuildRequires:  pkgconfig(libfwsi) >= 20240423
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
liblnk is a library and tools to access Windows Shortcut File (LNK) format files.

%package -n %lname
Summary:        Library to access the Windows Shortcut File (LNK) format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
liblnk is a library to access Windows Shortcut File (LNK) files.

%package tools
Summary:        Tools to access the Windows Shortcut File (LNK) format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
liblnk is a library to access Windows Shortcut File (LNK) files.

%package devel
Summary:        Development files for liblnk, a library to access Windows Shortcut Links
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
liblnk is a library to access Windows Shortcut File (LNK) files.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/liblnk.so.*

%files -n %name-tools
%_bindir/lnk*
%_mandir/man1/lnkinfo.1*

%files -n %name-devel
%doc Windows_Shortcut_File_*.pdf
%_includedir/liblnk.h
%_includedir/liblnk/
%_libdir/liblnk.so
%_libdir/pkgconfig/liblnk.pc
%_mandir/man3/liblnk.3*

%files %python_files
%license COPYING*
%python_sitearch/pylnk.so

%changelog
* Tue Apr 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240423
  * Add support for named properties
- Delete 0001-Changes-for-updates-to-libfwsi.patch (merged)
* Wed Feb 28 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Changes-for-updates-to-libfwsi.patch to resolve FTBFS
  with current libfwsi (20240225)
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sat Jan 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240120
  * No user-visible changes
* Mon Nov 20 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231120
  * Enhanced read-write lock support
* Mon Oct  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230928
  * Python 3.12 support
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sun Jul 16 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230716
  * Unspecified updates to format support and Python bindings
* Sun Feb  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230205
  * Python bindings update
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Sun Oct 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221023
  * Updates to dtfabric support
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables python2 on Leap 15)
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210417 (0c9a2c83)
  * No changelog was provided
- Add system-libs.patch
* Tue Dec 29 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200810
  * worked on python bindings
- added COPYING* to %%license line
- removed      BuildRequires:  pkg-config
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to disable python2 builds (bcond_without python2):
  Tumbleweed already declares this, as python2 is EOL.
* Tue Apr  7 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20191221
  * Worked on Python wheel support
  * Correction for reading location information device name #38
  * Changes for show_window and hot_key API functions
- rename python-liblnk to python2-liblnk
- add python3-liblnk submodule
* Thu Mar 28 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181227
  * Changes for handling location information strings
  * worked on Python bindings
  * various improvements associated with corrupt files
  * Fixed infinite loop in getopt fallback functions
  * Worked on dtfabric support (used by the developers, not an API issue)
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to v0~20160107
  * 2016 update
  * applied updates
  * worked on Python 3 support
  - added support for distributed link tracker functions
  * worked on Python bindings
  * worked on tests
  * worked on setup.py
  * bug fixes after fuzzing with AFL
  * Bug fix for handling volume label
* Tue Jan 13 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
- update source URL to point to new github site
- use new libyal packages from OBS instead of internal versions
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- update to v0~20141026
  * changes for deployment
  * worked on utility scripts
  * update Python-bindings tests
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to v0~20140905
  * bug fix in Python-bindings
  * worked on property store data block support
  * updated libfwsi version check
- change Source: field to fullpath, delete DL_URL
- use external libcerror package
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pylnk = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140731
  * bug fix in Python-bindings
  * worked on Python bindings
  - changes regarding integer object signedness on 32-bit architectures
  * worked on shell items support
  * small changes in debug output
  * small changes in lnkinfo output
  * updated dependencies
  * worked on updates
  * 2014 update
* Thu Nov 21 2013 Greg.Freemyer@gmail.com
- update to v0~20131015
  * updated dependencies
  * improved pyolecf as integer functions
  * worked on setup.py, largely for MSI builds
- cleanup BuildRequires statements
* Fri Sep 20 2013 Greg.Freemyer@gmail.com
- updated to v0~20130829
  * change to API to expose link target identifier data
  * fixes for building with stand-alone libuna and libbfio
  * updated dependencies
  * worked on automated tests
  * bug fix in pymsiecf file object libbfio glue code
  * worked on shell items
  - detection of delegate 0x2e item
  * fix in debug output for local path
  * worked on tests
  * textual changes
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- update to v0~20130413
  * updated dependencies
  * moved examples to project site
  * updated lnkinfo man page
  * worked on tests
  * updates and bug fixes in pylnk
  * fixed codepage 949, 950, 1255 restriction
  * added PackageMaker files
  * added functions to retrieve drive type, drive serial number and volume label
  * fix trailing \ for local and network path when common path is an emtpy string
- use gz compression to simplify download/convert
- use factory version of sub-packages as possible
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
- Drop Windows_Shell_Item pdf, this belongs to a different package
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130304) for build.opensuse.org
